## ----------------------------------------------------------------------------
## Boot and De Wit (1960)
##
## data
## availability: printed
## firms: General Motors, US Steel, General Electric, Chrysler, Atlantic Refining,
##        IBM, Union Oil, Westinghouse, Goodyear, Diamond Match
## errors: none
##
## analysis
## result: mostly exact at precision given
##         Westinghouse: error for intercept/variance
##           and tiny deviation for capital coef
##         US Steel: error in standard deviation of capital coef
##         Macro regression: interchanged standard deviations
##         Adjustment differences:
##           - wrong df for residual variance
##           - adjusted R^2 =  1 - (1 - R^2) * n/(n-k) instead of (n-1)/(n-k)
## ----------------------------------------------------------------------------

## preliminaries
source("start.R")

## data pre-processing
gr <- subset(Grunfeld, firm %in% c("General Motors", "US Steel", "General Electric", "Chrysler",
  "Atlantic Refining", "IBM", "Union Oil", "Westinghouse", "Goodyear", "Diamond Match"))
gr$firm <- factor(gr$firm)
pgr <- plm.data(gr, c("firm", "year"))

## summary statistics (Table 1, p. 8)
sort(tapply(gr$invest, gr$firm, mean), decreasing = TRUE)

## Microregressions (Table 2, p. 9)
lm_GM <- lm(invest ~ value + capital, data = gr, subset = firm == "General Motors")
gsummary(lm_GM)
var(residuals(lm_GM)) ## df = n-1 (instead of n-k)

lm_US <- lm(invest ~ value + capital, data = gr, subset = firm == "US Steel")
lm_GE <- lm(invest ~ value + capital, data = gr, subset = firm == "General Electric")
lm_CH <- lm(invest ~ value + capital, data = gr, subset = firm == "Chrysler")
lm_AR <- lm(invest ~ value + capital, data = gr, subset = firm == "Atlantic Refining")
lm_IBM<- lm(invest ~ value + capital, data = gr, subset = firm == "IBM")
lm_UO <- lm(invest ~ value + capital, data = gr, subset = firm == "Union Oil")
lm_WH <- lm(invest ~ value + capital, data = gr, subset = firm == "Westinghouse")
lm_GY <- lm(invest ~ value + capital, data = gr, subset = firm == "Goodyear")
lm_DM <- lm(invest ~ value + capital, data = gr, subset = firm == "Diamond Match")

## alternatively:
sf <- systemfit(invest ~ value + capital, method = "OLS", data = pgr)
gsummary(sf)
structure(
  sapply(sf$eq, function(x) var(residuals(x))),
  .Names = sapply(sf$eq, function(x) x$eqnLabel))
## df = n-1 (instead of n-k)
structure(
  sapply(sf$eq, function(x) 1 + (summary(x)$adj.r.squared - 1) * 20/19),
  .Names = sapply(sf$eq, function(x) x$eqnLabel))
## usually: adjusted R^2 = 1 - (1 - R^2) * (n-1)/(n-k)
## here:    adjusted R^2 = 1 - (1 - R^2) *  n   /(n-k)

## Macro regression (Equation 4.1, p. 10)
gr_macro <- aggregate(gr[,-4], list(gr$year), sum)[,-1]
lm_macro <- lm(invest ~ value + capital, data = gr_macro)
gsummary(lm_macro)
