## ----------------------------------------------------------------------------
## Grunfeld (1958)
##
## data
## availability: printed
## firms: General Motors, General Electric, US Steel, Atlantic Refining,
##        Union Oil, Diamond Match, Goodyear, American Steel, 
##        Chrysler, IBM, Westinghouse
## errors: none (by definition)
##
## analysis
## result: mostly minor variations re last digit,
##         General Motors: slopes and one s.e. (capital) are in error.
##           Reasons unclear.
##         Macro regression: discrepancies for all coef.s and se.s,
##           presumably due to discrepancies for GM.
## ----------------------------------------------------------------------------


## preliminaries
source("start.R")

## data pre-processing
gr8 <- subset(Grunfeld, firm %in% c("General Motors", "General Electric", "US Steel",
  "Atlantic Refining", "Union Oil", "Diamond Match", "Goodyear", "American Steel"))
gr8$firm <- factor(gr8$firm)
pgr8 <- plm.data(gr8, c("firm", "year"))

gr3 <- subset(Grunfeld, firm %in% c("IBM", "Chrysler", "Westinghouse"))
gr3$firm <- factor(gr3$firm)
pgr3 <- plm.data(gr3, c("firm", "year"))


# Table 25, p. 132 (constant terms not given)
lm_GM <- lm(invest ~ value + capital, data = gr8, subset = firm == "General Motors")
lm_GE <- lm(invest ~ value + capital, data = gr8, subset = firm == "General Electric")
lm_US <- lm(invest ~ value + capital, data = gr8, subset = firm == "US Steel")
lm_AR <- lm(invest ~ value + capital, data = gr8, subset = firm == "Atlantic Refining")
lm_UO <- lm(invest ~ value + capital, data = gr8, subset = firm == "Union Oil")
lm_DM <- lm(invest ~ value + capital, data = gr8, subset = firm == "Diamond Match")
lm_GY <- lm(invest ~ value + capital, data = gr8, subset = firm == "Goodyear")
lm_AS <- lm(invest ~ value + capital, data = gr8, subset = firm == "American Steel")

gsummary(lm_GM)
gsummary(lm_GE)
gsummary(lm_US)
gsummary(lm_AR)
gsummary(lm_UO)
gsummary(lm_DM)
gsummary(lm_GY)
gsummary(lm_AS)

## alternatively
sf8 <- systemfit(invest ~ value + capital, method = "OLS", data = pgr8)
gsummary(sf8)

## Macro regression (Table 25, col. "Aggr.")
gr8_macro <- aggregate(gr8[,-4], list(gr8$year), sum)[,-1]
lm_macro <- lm(invest ~ value + capital, data = gr8_macro)
gsummary(lm_macro)


## Table 30, p. 148 (constant terms not given)
## R^2s in Table 29, p. 146
lm_IBM <- lm(invest ~ value + capital, data = gr3, subset = firm == "IBM")
lm_CH <- lm(invest ~ value + capital, data = gr3, subset = firm == "Chrysler")
lm_WH <- lm(invest ~ value + capital, data = gr3, subset = firm == "Westinghouse")

gsummary(lm_IBM)
gsummary(lm_CH)
gsummary(lm_WH)

## alternatively
sf3 <- systemfit(invest ~ value + capital, method = "OLS", data = pgr3)
gsummary(sf3)


## aggregate regression using Grunfeld's Table 10 (Appendix), p. 164
## very different from gsummary(lm_macro)
lm_agg <- lm(invest ~ value + capital, data = Grunfeld_agg)
gsummary(lm_agg)
