## ----------------------------------------------------------------------------
## Koenker and Portnoy (1990)
##
## data
## availability: none
## firms: General Electric, Westinghouse
## errors: none
##
## analysis
## result: Table 1 - standard errors for SUR do not agree
##         Table 2 - Westinghouse M estimation slightly different
##         Table 3 - (NA)
## ----------------------------------------------------------------------------

## preliminaries
source("start.R")

## data pre-processing
gr <- subset(Grunfeld, firm %in% c("General Electric", "Westinghouse"))
gr$value <- gr$value/1000
gr$invest <- gr$invest/100
gr$capital <- gr$capital/100
gr$firm <- factor(gr$firm)
pgr <- plm.data(gr, c("firm", "year"))


## Table 1, p. 1063
## OLS
lm_OLS <- systemfit(invest ~ value + capital, method = "OLS", data = pgr)
gsummary(lm_OLS)
## alternatively:
## lm(invest ~ value + capital, data = gr, subset = firm == "General Electric")
## lm(invest ~ value + capital, data = gr, subset = firm == "Westinghouse")

## SUR
## these controls give the estimated "sigma matrix" and point estimates
sf_SUR <- systemfit(invest ~ value + capital, method = "SUR", data = pgr, 
                   control = systemfit.control(methodResidCov = "noDfCor"))
gsummary(sf_SUR)
round(summary(sf_SUR)$residCov, digits = 3)
 			   
## Table 2, p. 1064
## l_1 starting values
library("quantreg")
rq_GE <- rq(invest ~ value + capital, data = gr, subset = firm == "General Electric")
rq_WH <- rq(invest ~ value + capital, data = gr, subset = firm == "Westinghouse")
coef(rq_GE)
coef(rq_WH)

## M-estimation with custom psi function
library("MASS")
bread.rlm <- function(x, ...) {
  xmat <- model.matrix(x)
  xmat <- naresid(x$na.action, xmat)
  wts <- weights(x)
  if(is.null(wts)) wts <- 1
  res <- residuals(x)
  psi_deriv <- function(z) x$psi(z, deriv = 1)
  rval <- sqrt(abs(as.vector(psi_deriv(res/x$s)/x$s))) * wts * xmat    
  rval <- chol2inv(qr.R(qr(rval))) * nrow(xmat)
  return(rval)
}

## Koenker & Portnoy psi function
psi.kp <- function(u, a = 0.99, b = 0.4, deriv = 0) {
  lambda <- log((a + 1)/(1 - a)) / qnorm(1 - b)
  if(!deriv) ifelse(u == 0, 0, (-(1 - 2/(1 + exp(-lambda * u))))/u)
    else lambda * 2/(1 + exp(-lambda * u))^2 * exp(-lambda * u)
}

## Table 2, p. 1064
## M estimation (coefficients and standard errors)
rlm_GE <- rlm(invest ~ value + capital, data = gr, subset = firm == "General Electric",
  psi = psi.kp, init = coef(rq_GE), maxit = 100, acc = 1e-10)
rlm_WH <- rlm(invest ~ value + capital, data = gr, subset = firm == "Westinghouse",
  psi = psi.kp, init = coef(rq_WH), maxit = 100, acc = 1e-10)
round(coeftest(rlm_GE, vcov = sandwich)[,1:2], digits = 3)
round(coeftest(rlm_WH, vcov = sandwich)[,1:2], digits = 3)

## Table 3, p. 1064
## (would require some more coding)
