## ----------------------------------------------------------------------------
## Theil (1971) -> Zellner (1962)
##
## data
## availability: printed
## firms: General Electric, Westinghouse
## errors: none
##
## analysis
## result: exact at precision given
## ----------------------------------------------------------------------------

## preliminaries
source("start.R")

## data pre-processing
gr <- subset(Grunfeld, firm %in% c("General Electric", "Westinghouse"))
gr$firm <- factor(gr$firm)
pgr <- plm.data(gr, c("firm", "year"))

## OLS (p. 295) 
fmGE <- lm(invest ~ value + capital, data = gr, subset = firm == "General Electric")
fmWH <- lm(invest ~ value + capital, data = gr, subset = firm == "Westinghouse")
summary(fmGE)
summary(fmWH)
## alternatively:
## systemfit(invest ~ value + capital, method = "OLS", data = pgr)


## SUR (p. 300)
fm <- systemfit(invest ~ value + capital, method = "SUR", data = pgr,
  control = systemfit.control(methodResidCov = "noDfCor"))
gsummary(fm)

## matrix of mean squares and products (p. 299)
summary(fm)$residCovEst * 20

## covariance matrices (p. 301)
vcov(fmGE) * 17/20 * 1e6
vcov(fmWH) * 17/20 * 1e6
vcov(fm)
