## ----------------------------------------------------------------------------
## Zellner (1962)
##
## data
## availability: none
## firms: General Electric, Westinghouse
## errors: (none)
##
## analysis
## result: OLS exact at precision given
## only minor deviations at last significant digit for some variances
## SUR estimates not reproducible due to algebraic error on p. 359
## ----------------------------------------------------------------------------

source("start.R")

gr <- subset(Grunfeld, firm %in% c("General Electric", "Westinghouse"))
gr$firm <- factor(gr$firm)
pgr <- plm.data(gr, c("firm", "year"))

## Two-Stage Aitken Method (Table 1, p. 360)
## ??

## OLS estimation (Table 1, p. 360)
fmGE <- lm(invest ~ value + capital, data = gr, subset = firm == "General Electric")
fmWH <- lm(invest ~ value + capital, data = gr, subset = firm == "Westinghouse")
diag(vcov(fmGE))
diag(vcov(fmWH))
## alternatively:
## fm <- systemfit(invest ~ value + capital, method = "OLS", data = pgr)


## computations leading to two-stage estimates
## p. 358
mmGE <- as.matrix(cbind(model.frame(fmGE), 1))
mmWH <- as.matrix(cbind(model.frame(fmWH), 1))

## moment matrices
crossprod(mmGE)
crossprod(mmGE, mmWH)
crossprod(mmWH)

## p. 359 (higher precision than in Tab. 1)
coef(fmGE)
coef(fmWH)

## Scaled Sigma matrix for multivariate linear model (p. 359, middle), not reproducible
Y <- cbind(gr[1:20, 1], gr[21:40, 1])
X <- as.matrix(cbind(gr[1:20, 3:2], 1, gr[21:40, 3:2], 1))
B <- rbind( cbind(coef(fmGE)[3:1], 0), cbind(0, coef(fmWH)[3:1]) )
crossprod((Y - X %*% B))

## for comparison
fmSUR <- systemfit(invest ~ value + capital, data = pgr, method = "SUR",
  control = systemfit.control(methodResidCov = "noDfCor"))
fmSUR$residCov * 20

